<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Media.Core.Preview

Windows Runtime (WinRT) APIs for for the `Windows.Media.Core.Preview` namespace.

This package provides the `winrt.windows.media.core.preview` module.
